Madison County Mississippi - - Madison County, MS
Author: Madison County, Mississippi

## Welcome

Thank you for visiting our website. Madison County is one of the fastest growing counties in Mississippi, yet we have sought to remain a small, friendly community full of rich history and looking forward to a bright future. Named for the fourth president of the United States, James Madison, the 23rd county in Mississippi was created in 1828 from portions of Yazoo and Hinds counties. This area attracted a large number of settlers from Virginia and the Carolinas who came to farm the lush, rolling hills and fertile soil. Today Madison County is home to a number of thriving businesses.

Elected Offices
  Board of Supervisors
  District Attorney
  Chancery Clerk
  Election Commission
  Circuit Clerk
  Sheriff's Department
  Constables
  Tax Assessor
  Coroner
  Tax Collector
  County Prosecutor

County Departments
  Administrator
  Building and Grounds
  Comptroller
  Economic Development (offsite link)
  Emergency Management
  Fire Services
  Geographic Information Systems
  Human Resources
  Information Technology
  Planning and Zoning
  Purchasing
  Road Department
  Solid Waste / Recycling
  Veteran Services
  Wastewater Authority

Court Systems
  Chancery Court
  Circuit Court
  County Court
  Justice Court
  Youth Court

# Newswire

- ##### E-Recording of Land Records

  April 01, 2015

- ##### Madison County Emergency Management

  September 11, 2015

- ##### Madison County Offices Holiday Closure

  December 25, 2015

Click here to view all news items >

Madison County Land and Personal Property Taxes for 2014-2015 now online

Scam Alert! Click to Read More